chembl_webresource_client
======

.. image:: https://pypip.in/version/chembl_webresource_client/badge.svg
    :target: https://pypi.python.org/pypi/chembl_webresource_client/
    :alt: Latest Version

.. image:: https://pypip.in/download/chembl_webresource_client/badge.svg
    :target: https://pypi.python.org/pypi/chembl_webresource_client/
    :alt: Downloads

.. image:: https://pypip.in/py_versions/chembl_webresource_client/badge.svg
    :target: https://pypi.python.org/pypi/chembl_webresource_client/
    :alt: Supported Python versions

.. image:: https://pypip.in/status/chembl_webresource_client/badge.svg
    :target: https://pypi.python.org/pypi/chembl_webresource_client/
    :alt: Development Status

.. image:: https://pypip.in/license/chembl_webresource_client/badge.svg
    :target: https://pypi.python.org/pypi/chembl_webresource_client/
    :alt: License

.. image:: https://badge.waffle.io/chembl/chembl_webresource_client.png?label=ready&title=Ready&style=flat 
 :target: https://waffle.io/chembl/chembl_webresource_client
 :alt: 'Stories in Ready'

.. image:: https://travis-ci.org/chembl/chembl_webresource_client.svg?branch=master
    :target: https://travis-ci.org/chembl/chembl_webresource_client

This is chembl_webresource_client package developed at Chembl group, EMBL-EBI, Cambridge, UK.

This package implements python client for accessing ChEMBL webservices.
It provides convenient interface to access data, cache results and optionally executes requests in asynchronous manner.
